@@ -1,11 +1,12 @@
 package Data::Morph;
 {
-  $Data::Morph::VERSION = '1.112730';
+  $Data::Morph::VERSION = '1.112760';
 }
 
 #ABSTRACT: Morph data from one source to another
 
 use Moose;
+use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose(':all');
 use MooseX::Types::Structured(':all');
 use MooseX::Params::Validate;
@@ -33,16 +34,16 @@ has map =>
             (
                 Str|Dict
                 [
-                    read => (Str|Tuple[Str, CodeRef]),
-                    write => (Str|Tuple[Str, CodeRef]),
+                    read => union( [Maybe[Str], Tuple[Str, CodeRef]] ),
+                    write => Optional[Str|Tuple[Str, CodeRef]],
                 ]
             ),
             recto =>
             (
                 Str|Dict
                 [
-                    read => (Str|Tuple[Str, CodeRef]),
-                    write => (Str|Tuple[Str, CodeRef]),
+                    read => union( [Maybe[Str], Tuple[Str, CodeRef]] ),
+                    write => Optional[Str|Tuple[Str, CodeRef]],
                 ]
             )
         ]
@@ -75,6 +76,9 @@ sub _build_morpher
         {
             my ($recto_map, $verso_map) = @$entry{qw/recto verso/};
 
+            next if ref($verso_map) and
+                (!exists($verso_map->{write}) || !defined($verso_map->{write}));
+
             my $val = $recto->retrieve
             (
                 $input,
@@ -115,6 +119,9 @@ sub _build_morpher
         {
             my ($recto_map, $verso_map) = @$entry{qw/recto verso/};
 
+            next if ref($recto_map) and
+                (!exists($recto_map->{write}) || !defined($recto_map->{write}));
+
             my $val = $verso->retrieve
             (
                 $input,
@@ -174,7 +181,7 @@ Data::Morph - Morph data from one source to another
 
 =head1 VERSION
 
-version 1.112730
+version 1.112760
 
 =head1 SYNOPSIS
 
@@ -285,16 +292,16 @@ the type of the input.
             (
                 Str|Dict
                 [
-                    read => (Str|Tuple[Str, CodeRef]),
-                    write => (Str|Tuple[Str, CodeRef]),
+                    read => union( [Maybe[Str], Tuple[Str, CodeRef]] ),
+                    write => Optional[Str|Tuple[Str, CodeRef]],
                 ]
             ),
             recto =>
             (
                 Str|Dict
                 [
-                    read => (Str|Tuple[Str, CodeRef]),
-                    write => (Str|Tuple[Str, CodeRef]),
+                    read => union( [Maybe[Str], Tuple[Str, CodeRef]] ),
+                    write => Optional[Str|Tuple[Str, CodeRef]],
                 ]
             )
         ]
@@ -352,6 +359,34 @@ needs to be stripped before morphing back.
 Each hash in the map array is executed in the order in which it is defined. This
 is important if there are order dependant operations.
 
+If a data element only flows one way through the process, do not define a write
+element for the given recto/verso, but just a read element.
+
+As an example, suppose the object on one side of the transaction needs a constant
+not provided by the incoming data. With read-only elements and a coderef, this
+constant can be provided:
+
+    my $map = [
+        {
+            recto =>
+            {
+                read => 'get_foo',
+                write => 'set_foo',
+            },
+            verso =>
+            {
+                read => [ 'some_key', sub { 42 } ],
+            }
+        }
+    ];
+
+Now when going verso -> recto with the data, for the 'foo' attribute on the
+object, it will always get the constant. When going recto -> verso, there is no
+write defined and so the element is skipped.
+
+Please note that the value of 'some_key' will be discarded due to the post-read
+coderef. Setting the key to undef will ensure just the coderef is executed.
+
 =head1 PRIVATE_ATTRIBUTES
 
 =head2 morpher
